@@ -15,11 +15,18 @@
 */
 
 #include <ctype.h>
-#include <unistd.h>
-#include <sys/param.h>
 #include "parser.h"
 #include "thrift/rpc_thrift_enum.h"
 
+#ifndef _WIN32
+#include <unistd.h>
+#include <sys/param.h>
+#else
+#define MAXPATHLEN 4096
+#include <direct.h>
+#endif
+
+
 #define LINE_LENGTH_MAX 2048
 
 static std::string gen_param_var(const std::string& type_name, size_t& cur,
@@ -328,18 +335,21 @@ std::string Parser::find_typedef_mapping_type(std::string& type_name,
 	{
 		auto key_type = find_typedef_mapping_type(type_name, ++cur, info);
 		auto val_type = find_typedef_mapping_type(type_name, ++cur, info);
+		++cur;
 		return "std::map<" + key_type + ", " + val_type + ">";
 	}
 	else if (idl_type == "std::set" && cur < type_name.size() &&
 			 type_name[cur] == '<')
 	{
 		auto val_type = find_typedef_mapping_type(type_name, ++cur, info);
+		++cur;
 		return "std::set<" + val_type + ">";
 	}
 	else if (idl_type == "std::vector" && cur < type_name.size() &&
 			 type_name[cur] == '<')
 	{
 		auto val_type = find_typedef_mapping_type(type_name, ++cur, info);
+		++cur;
 		return "std::vector<" + val_type + ">";
 	}
 
@@ -606,18 +616,21 @@ static std::string gen_param_var(const std::string& type_name, size_t& cur,
 	{
 		auto key_type = gen_param_var(type_name, ++cur, info);
 		auto val_type = gen_param_var(type_name, ++cur, info);
+		++cur;
 		return "std::map<" + key_type + ", " + val_type + ">";
 	}
 	else if (idl_type == "set" && cur < type_name.size() &&
 			 type_name[cur] == '<')
 	{
 		auto val_type = gen_param_var(type_name, ++cur, info);
+		++cur;
 		return "std::set<" + val_type + ">";
 	}
 	else if (idl_type == "list" && cur < type_name.size() &&
 			 type_name[cur] == '<')
 	{
 		auto val_type = gen_param_var(type_name, ++cur, info);
+		++cur;
 		return "std::vector<" + val_type + ">";
 	}
 
@@ -753,16 +766,16 @@ bool Parser::parse_rpc_param_thrift(const std::string& file_name_prefix,
 	std::string idl_type;
 	if (left_b + 1 < str.size())
 	{
-		auto bb = SGenUtil::split_filter_empty(str.substr(left_b + 1), ',');
+		auto bb = SGenUtil::split_skip_string(str.substr(left_b + 1), ',');
 		for (const auto& ele : bb)
 		{
-			auto filedparam = SGenUtil::split_filter_empty(ele, ':');
+			auto filedparam = SGenUtil::split_skip_string(ele, ':');
 			if (filedparam.size() != 2)
 			  continue;
 
-			auto typevar = SGenUtil::split_filter_empty(filedparam[1], ' ');
+			auto typevar = SGenUtil::split_skip_string(filedparam[1], ' ');
 			if (typevar.size() != 2)
-			  continue;
+				continue;
 
 			param.var_name = typevar[1];
 			param.required_state = srpc::THRIFT_STRUCT_FIELD_REQUIRED;
@@ -811,7 +824,7 @@ bool Parser::parse_service_thrift(const std::string& file_name_prefix,
 		if (left_b == std::string::npos)
 			continue;
 
-		auto aa = SGenUtil::split_filter_empty(line.substr(0, left_b), ' ');
+		auto aa = SGenUtil::split_skip_string(line.substr(0, left_b), ' ');
 		if (aa.size() != 2)
 			continue;
 
@@ -889,7 +902,7 @@ bool Parser::parse_enum_thrift(const std::string& block, Descriptor& desc)
 		if (valid_block[i] == '\n' || valid_block[i] == '\r' || valid_block[i] == ',')
 			valid_block[i] = ';';
 
-	auto arr = SGenUtil::split_filter_empty(valid_block, ';');
+	auto arr = SGenUtil::split_skip_string(valid_block, ';');
 
 	for (const auto& ele : arr)
 	{
@@ -917,19 +930,35 @@ bool Parser::parse_struct_thrift(const std::string& file_name_prefix,
 
 	std::string valid_block = block.substr(st + 1, ed - st - 1);
 	int deep = 0;
+	bool in_string = false;
 	for (size_t i = 0; i < valid_block.size(); i++)
 	{
-		if (valid_block[i] == '\n' || valid_block[i] == '\r')
+		int c = valid_block[i];
+		if (c == '\n' || c == '\r')
+		{
 			valid_block[i] = ';';
-		else if (valid_block[i] == ',' && deep == 0)
+			in_string = false;
+		}
+		else if (c == ',' && !in_string && deep == 0)
 			valid_block[i] = ';';
-		else if (valid_block[i] == '<')
+		else if (c == '<' && !in_string)
 			deep++;
-		else if (valid_block[i] == '>')
+		else if (c == '>' && !in_string)
 			deep--;
+		else if (c == '[' && !in_string)
+			valid_block[i] = '{';
+		else if (c == ']' && !in_string)
+			valid_block[i] = '}';
+		else if (c == '\"')
+			in_string = !in_string;
+		else if (in_string && c == '\\')
+		{
+			if (i + 1 < valid_block.size())
+				i++;
+		}
 	}
 
-	auto arr = SGenUtil::split_filter_empty(valid_block, ';');
+	auto arr = SGenUtil::split_skip_string(valid_block, ';');
 
 	for (const auto& ele : arr)
 	{
@@ -937,7 +966,7 @@ bool Parser::parse_struct_thrift(const std::string& file_name_prefix,
 		if (line.empty())
 			continue;
 
-		auto aabb = SGenUtil::split_filter_empty(line, ':');
+		auto aabb = SGenUtil::split_skip_string(line, ':');
 		if (aabb.size() != 2)
 			continue;
 
@@ -949,7 +978,7 @@ bool Parser::parse_struct_thrift(const std::string& file_name_prefix,
 		param.field_id = atoi(aa.c_str());
 
 		auto bb = SGenUtil::strip(aabb[1]);
-		auto bbcc = SGenUtil::split_filter_empty(bb, '=');
+		auto bbcc = SGenUtil::split_skip_string(bb, '=');
 		if (bbcc.size() == 2)
 		{
 			bb = SGenUtil::strip(bbcc[0]);
